@@ -5,7 +5,8 @@ sub Mojo::Webqq::Message::_send_message{
         my $status = $self->parse_send_status_msg( $json );
         if(defined $status and !$status->is_success){
             $self->debug("消息[ " .$msg->msg_id . " ]发送失败，尝试重新发送，当前TTL: " . $msg->ttl);
-            $self->send_message($msg);
+            $self->message_queue->put($msg);
+            #$self->send_message($msg);
             return;
         }
         elsif(defined $status){
